"""A credential content message."""

from marshmallow import fields

from ...agent_message import AgentMessage, AgentMessageSchema
from ..message_types import CREDENTIAL_ISSUE

HANDLER_CLASS = (
    "aries_cloudagent.messaging.credentials.handlers."
    + "credential_issue_handler.CredentialIssueHandler"
)


class CredentialIssue(AgentMessage):
    """Class representing a credential."""

    class Meta:
        """Credential metadata."""

        handler_class = HANDLER_CLASS
        schema_class = "CredentialIssueSchema"
        message_type = CREDENTIAL_ISSUE

    def __init__(self, *, issue: str = None, **kwargs):
        """
        Initialize credential object.

        Args:
            issue (str): Credential issue json string
        """
        super(CredentialIssue, self).__init__(**kwargs)
        self.issue = issue


class CredentialIssueSchema(AgentMessageSchema):
    """Credential schema."""

    class Meta:
        """Credential schema metadata."""

        model_class = CredentialIssue

    issue = fields.Str(required=True)
